@@ -481,6 +481,7 @@ OC.L10N.register(
     "Blocked" : "Stanket",
     "Active" : "O labourat",
     "Expired" : "Termenet",
+    "Never" : "James",
     "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
     "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
@@ -493,6 +494,7 @@ OC.L10N.register(
     "Created at" : "Krouet da",
     "Expires at" : "Termen da",
     "Limits" : "Bevennoù",
+    "No" : "Nann",
     "Delete the signaling server account" : "Lemel ar c'hont arhent servijour",
     "_%n user_::_%n users_" : ["%n implijer","%n implijer","%n implijer","%n implijer","%n implijer"],
     "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
@@ -522,6 +524,7 @@ OC.L10N.register(
     "Search participants" : "Klask implijer",
     "No results" : "Disoc'h ebet",
     "Done" : "Graet",
+    "Grid view" : "Diskwell ar roued",
     "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
     "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
@@ -529,6 +532,7 @@ OC.L10N.register(
     "Copy link" : "Kopiañ al liamm",
     "Mute audio" : "Lac'hañ a audio",
     "Unmute audio" : "Lakaat an odio en dro",
+    "None" : "Hini ebet",
     "Access to camera was denied" : "Nac'het eo bet tizhañ ar c'hamera",
     "Error while accessing camera" : "Ur fazi a zo bet en ur tizhout ar c'hamera",
     "You have been muted by a moderator" : "Mut oc'h bet lakaet gant ar moderatour",
@@ -552,7 +556,6 @@ OC.L10N.register(
     "Personal" : "Personel",
     "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Leave conversation" : "Kuitaat an diviz",
-    "No" : "Nann",
     "Delete conversation" : "Dilemel an diviz",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
@@ -567,6 +570,7 @@ OC.L10N.register(
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
     "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
+    "Home" : "Degemer",
     "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
     "Users" : "Implijer",
     "Groups" : "Strolladoù",
@@ -574,13 +578,17 @@ OC.L10N.register(
     "Users and groups" : "Implijourienn ha strolladoù",
     "Other sources" : "Orin all",
     "You are currently waiting in the lobby" : "Ho gortoz er sal gortoz emaoc'h",
-    "None" : "Hini ebet",
     "Select microphone" : "Choaz ur mikro",
     "No microphone available" : "Mikro ebet kavet",
     "Select camera" : "Choaz ur c'hamera",
     "No camera available" : "Kamera ebet kavet",
     "No audio" : "Audio ebet",
     "No camera" : "Kamera ebet",
+    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
+    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
+    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
+    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
+    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Upload" : "Pellkas",
     "Files" : "Restroù",
@@ -589,15 +597,11 @@ OC.L10N.register(
     "Translate" : "Treiñ",
     "Dismiss" : "Arrest",
     "Translate to" : "Treiñ e",
-    "Today" : "Hiziv",
-    "Yesterday" : "Dec'h",
-    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
     "Add participants" : "Ouzhpennan tud",
     "Send message" : "Kas ur gemenadenn",
-    "Add emoji" : "Ouzhpennañ un emoji",
     "File to share" : "Restr da rannañ",
+    "Add emoji" : "Ouzhpennañ un emoji",
     "Share from Files" : "Rannañ diouzh Restroù",
     "Share files to the conversation" : "Rannañ restroù d'an diviz",
     "New file" : "Restr nevez",
@@ -621,18 +625,13 @@ OC.L10N.register(
     "Details" : "Munudoù",
     "Load more results" : "Kagañ muioc'h a disoc'hoù",
     "Projects" : "Raktres",
+    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Link to a conversation" : "Liamm d'an diviz",
     "Search conversations or users" : "Klask divizoù ha implijourienn",
     "Select conversation" : "Choaz un diviz",
-    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
-    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
-    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
-    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
-    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
-    "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
-    "Choose devices" : "Choazit un ardivink",
-    "Attachments folder" : "Teuliad stag",
     "Select location for attachments" : "Choazit ul lec'h evit stagañ",
+    "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
+    "Attachments folder" : "Teuliad stag",
     "Privacy" : "Prevezder",
     "Search" : "Klask",
     "Start call" : "Kregiñ ar gemenadenn",
@@ -655,16 +654,13 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
     "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
-    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
     "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
     "Show your screen" : "Diskouez ar skramm",
     "Stop screensharing" : "Echuañ ar rannadenn skramm",
-    "Grid view" : "Diskwell ar roued",
     "Mute others" : "Lakaat ar re all mut",
     "Keep" : "Mirout",
     "Submit" : "Kinnig",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
@@ -679,9 +675,9 @@ OC.L10N.register(
     "Media" : "Media",
     "Audio" : "Audio",
     "Other" : "All",
+    "Default" : "Dre ziouer",
     "Group" : "Stollad",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
     "Leave this page" : "Kuitaat ar bajenn",
     "Join here" : "Kejañ amañ",
@@ -693,7 +689,6 @@ OC.L10N.register(
     "Please reload the page." : "Mar-plij adkargit ar bajenn",
     "Do not disturb" : "Na rannit ket",
     "Away" : "Pell",
-    "Default" : "Dre ziouer",
     "Microphone {number}" : "Mikro {number}",
     "Camera {number}" : "Kamera {number}",
     "Speaker {number}" : "Huel-gomzerioù {number}",
@@ -719,8 +714,15 @@ OC.L10N.register(
     "Join »%s«" : "Mont da »%s«",
     "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
     "Copy conversation link" : "Eilañ al liamm diviz",
+    "Today" : "Hiziv",
+    "Yesterday" : "Dec'h",
+    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
     "Close" : "Serriñ",
+    "Choose devices" : "Choazit un ardivink",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
+    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
     "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
     "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
