@@ -398,6 +398,7 @@ OC.L10N.register(
     "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
     "Password protection" : "Protección con contraseña",
     "Set a password" : "Establecer una contraseña",
+    "Invalid language" : "Idioma inválido",
     "Edit" : "Editar",
     "Delete" : "Eliminar",
     "Log content" : "Contenido de bitácoras",
@@ -407,6 +408,7 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Home" : "Inicio",
     "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
     "Users" : " Usuarios",
@@ -431,10 +433,6 @@ OC.L10N.register(
     "Translate from" : "Traducir desde",
     "Contact" : "Contacto",
     "Copy code block" : "Copiar bloque de código",
-    "Today" : "Hoy",
-    "Yesterday" : "Ayer",
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Sin mensajes",
     "Share from Files" : "Compartir desde Archivos",
     "Upload from device" : "Cargar desde el dispositivo",
@@ -467,18 +465,15 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
     "More actions" : "Más acciones",
-    "Default" : "Predeterminado",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
     "Keep" : "Mantener",
     "Submit" : "Enviar",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Talk conversation" : "Conversación de Talk",
     "User" : "Usuario",
@@ -493,6 +488,7 @@ OC.L10N.register(
     "Audio" : "Audio",
     "Other" : "Otro",
     "Show all files" : "Mostrar todos los archivos",
+    "Default" : "Predeterminado",
     "Group" : "Grupo",
     "Team" : "Equipo",
     "Error while sharing file" : "Error al compartir el archivo",
@@ -519,6 +515,12 @@ OC.L10N.register(
     "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
     "Join »%s«" : "Unirse »%s«",
     "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
-    "Close" : "Cerrar"
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Close" : "Cerrar",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
