@@ -377,6 +377,7 @@ OC.L10N.register(
     "Blocked" : "נחסם",
     "Active" : "פעיל",
     "Expired" : "פג",
+    "Never" : "מעולם לא",
     "Language" : "שפה",
     "Country" : "מדינה",
     "Status" : "מצב",
@@ -484,10 +485,6 @@ OC.L10N.register(
     "Translate" : "תרגום",
     "Dismiss" : "התעלמות",
     "Contact" : "איש/אשת קשר",
-    "Today" : "היום",
-    "Yesterday" : "מחר",
-    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "אין הודעות",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Add participants" : "הוספת משתתפים",
@@ -533,13 +530,9 @@ OC.L10N.register(
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
     "More actions" : "פעולות נוספות",
     "Start call" : "התחלת שיחה",
-    "Default" : "בררת מחדל",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
     "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Show your screen" : "הצגת המסך שלך",
     "Stop screensharing" : "הפסקת שיתוף המסך",
@@ -547,6 +540,7 @@ OC.L10N.register(
     "Keep" : "שימור",
     "Select a region" : "נא לבחור איזור",
     "Submit" : "שליחה",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
     "The conversation does not exist" : "הדיון לא קיים",
@@ -589,6 +583,7 @@ OC.L10N.register(
     "Locations" : "מיקומים",
     "Audio" : "שמע",
     "Other" : "אחר",
+    "Default" : "בררת מחדל",
     "Group" : "קבוצה",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
@@ -611,7 +606,13 @@ OC.L10N.register(
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Copy conversation link" : "העתקת קישור דיון",
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
     "Close" : "סגירה",
-    "Choose devices" : "בחירת התקנים"
+    "Choose devices" : "בחירת התקנים",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך."
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
