@@ -3,25 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2024 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Federation\Proxy\TalkV1\Controller;
@@ -51,7 +34,7 @@ class ChatController {
 	protected ?ICache $proxyCacheMessages;
 
 	public function __construct(
-		protected ProxyRequest  $proxy,
+		protected ProxyRequest $proxy,
 		protected UserConverter $userConverter,
 		protected ParticipantService $participantService,
 		protected RoomFormatter $roomFormatter,
@@ -64,7 +47,7 @@ class ChatController {
 	/**
 	 * @see \OCA\Talk\Controller\ChatController::sendMessage()
 	 *
-	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE|Http::STATUS_TOO_MANY_REQUESTS, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE|Http::STATUS_TOO_MANY_REQUESTS, array{error: string}, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 * 201: Message sent successfully
@@ -73,7 +56,7 @@ class ChatController {
 	 * 413: Message too long
 	 * 429: Mention rate limit exceeded (guests only)
 	 */
-	public function sendMessage(Room $room, Participant $participant, string $message, string $referenceId, int $replyTo, bool $silent): DataResponse {
+	public function sendMessage(Room $room, Participant $participant, string $message, string $referenceId, int $replyTo, bool $silent, string $threadTitle, int $threadId): DataResponse {
 		$proxy = $this->proxy->post(
 			$participant->getAttendee()->getInvitedCloudId(),
 			$participant->getAttendee()->getAccessToken(),
@@ -84,6 +67,8 @@ class ChatController {
 				'referenceId' => $referenceId,
 				'replyTo' => $replyTo,
 				'silent' => $silent,
+				'threadTitle' => $threadTitle,
+				'threadId' => $threadId,
 			],
 		);
 
@@ -97,7 +82,9 @@ class ChatController {
 			], true)) {
 				$statusCode = $this->proxy->logUnexpectedStatusCode(__METHOD__, $statusCode);
 			}
-			return new DataResponse([], $statusCode);
+			/** @var array{error: string} $data */
+			$data = $this->proxy->getOCSData($proxy, [Http::STATUS_CREATED]);
+			return new DataResponse($data, $statusCode);
 		}
 
 		/** @var ?TalkChatMessageWithParent $data */
@@ -110,7 +97,7 @@ class ChatController {
 
 		$headers = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$headers['X-Chat-Last-Common-Read'] = (string) (int) $proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)(int)$proxy->getHeader('X-Chat-Last-Common-Read');
 		}
 
 		return new DataResponse(
@@ -121,7 +108,7 @@ class ChatController {
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMessageWithParent[], array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, array<empty>, array<empty>>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 *  200: Messages returned
@@ -151,7 +138,7 @@ class ChatController {
 		if ($lookIntoFuture) {
 			if ($this->proxyCacheMessages instanceof ICache) {
 				for ($i = 0; $i <= $timeout; $i++) {
-					$cacheData = (int) $this->proxyCacheMessages->get($cacheKey);
+					$cacheData = (int)$this->proxyCacheMessages->get($cacheKey);
 					if ($lastKnownMessageId !== $cacheData) {
 						break;
 					}
@@ -186,7 +173,7 @@ class ChatController {
 				0,
 				false,
 				false,
-				(int) ($proxy->getHeader('X-Chat-Last-Given') ?: $lastKnownMessageId),
+				(int)($proxy->getHeader('X-Chat-Last-Given') ?: $lastKnownMessageId),
 			);
 		}
 
@@ -197,33 +184,33 @@ class ChatController {
 					$this->proxyCacheMessages->set($cacheKey, $lastKnownMessageId, 300);
 				}
 			}
-			return new DataResponse([], Http::STATUS_NOT_MODIFIED);
+			return new DataResponse(null, Http::STATUS_NOT_MODIFIED);
 		}
 
 		$headers = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$headers['X-Chat-Last-Common-Read'] = (string) (int) $proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)(int)$proxy->getHeader('X-Chat-Last-Common-Read');
 		}
 		if ($proxy->getHeader('X-Chat-Last-Given')) {
-			$headers['X-Chat-Last-Given'] = (string) (int) $proxy->getHeader('X-Chat-Last-Given');
+			$headers['X-Chat-Last-Given'] = (string)(int)$proxy->getHeader('X-Chat-Last-Given');
 			if ($lookIntoFuture && $this->proxyCacheMessages instanceof ICache) {
 				$cacheData = $this->proxyCacheMessages->get($cacheKey);
 				if ($cacheData === null || $cacheData < $headers['X-Chat-Last-Given']) {
-					$this->proxyCacheMessages->set($cacheKey, (int) $headers['X-Chat-Last-Given'], 300);
+					$this->proxyCacheMessages->set($cacheKey, (int)$headers['X-Chat-Last-Given'], 300);
 				}
 			}
 		}
 
-		/** @var TalkChatMessageWithParent[] $data */
+		/** @var list<TalkChatMessageWithParent> $data */
 		$data = $this->proxy->getOCSData($proxy);
-		/** @var TalkChatMessageWithParent[] $data */
+		/** @var list<TalkChatMessageWithParent> $data */
 		$data = $this->userConverter->convertMessages($room, $data);
 
 		return new DataResponse($data, Http::STATUS_OK, $headers);
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMessageWithParent[], array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, array<empty>, array<empty>>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 * 200: Message context returned
@@ -246,27 +233,27 @@ class ChatController {
 		}
 
 		if ($proxy->getStatusCode() === Http::STATUS_NOT_MODIFIED) {
-			return new DataResponse([], Http::STATUS_NOT_MODIFIED);
+			return new DataResponse(null, Http::STATUS_NOT_MODIFIED);
 		}
 
 		$headers = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$headers['X-Chat-Last-Common-Read'] = (string) (int) $proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)(int)$proxy->getHeader('X-Chat-Last-Common-Read');
 		}
 		if ($proxy->getHeader('X-Chat-Last-Given')) {
-			$headers['X-Chat-Last-Given'] = (string) (int) $proxy->getHeader('X-Chat-Last-Given');
+			$headers['X-Chat-Last-Given'] = (string)(int)$proxy->getHeader('X-Chat-Last-Given');
 		}
 
-		/** @var TalkChatMessageWithParent[] $data */
+		/** @var list<TalkChatMessageWithParent> $data */
 		$data = $this->proxy->getOCSData($proxy);
-		/** @var TalkChatMessageWithParent[] $data */
+		/** @var list<TalkChatMessageWithParent> $data */
 		$data = $this->userConverter->convertMessages($room, $data);
 
 		return new DataResponse($data, Http::STATUS_OK, $headers);
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 * 200: Message edited successfully
@@ -314,7 +301,7 @@ class ChatController {
 
 		$headers = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$headers['X-Chat-Last-Common-Read'] = (string) (int) $proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)(int)$proxy->getHeader('X-Chat-Last-Common-Read');
 		}
 
 		return new DataResponse(
@@ -325,7 +312,7 @@ class ChatController {
 	}
 
 	/**
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED, array{error: string}, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 * 200: Message deleted successfully
@@ -365,7 +352,7 @@ class ChatController {
 
 		$headers = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$headers['X-Chat-Last-Common-Read'] = (string) (int) $proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)(int)$proxy->getHeader('X-Chat-Last-Common-Read');
 		}
 
 		return new DataResponse(
@@ -407,8 +394,8 @@ class ChatController {
 
 		$headers = $lastCommonRead = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$lastCommonRead[$room->getId()] = (int) $proxy->getHeader('X-Chat-Last-Common-Read');
-			$headers['X-Chat-Last-Common-Read'] = (string) $lastCommonRead[$room->getId()];
+			$lastCommonRead[$room->getId()] = (int)$proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)$lastCommonRead[$room->getId()];
 		}
 
 		return new DataResponse($this->roomFormatter->formatRoom(
@@ -448,8 +435,8 @@ class ChatController {
 
 		$headers = $lastCommonRead = [];
 		if ($proxy->getHeader('X-Chat-Last-Common-Read')) {
-			$lastCommonRead[$room->getId()] = (int) $proxy->getHeader('X-Chat-Last-Common-Read');
-			$headers['X-Chat-Last-Common-Read'] = (string) $lastCommonRead[$room->getId()];
+			$lastCommonRead[$room->getId()] = (int)$proxy->getHeader('X-Chat-Last-Common-Read');
+			$headers['X-Chat-Last-Common-Read'] = (string)$lastCommonRead[$room->getId()];
 		}
 
 		return new DataResponse($this->roomFormatter->formatRoom(
@@ -463,7 +450,7 @@ class ChatController {
 	/**
 	 * @see \OCA\Talk\Controller\ChatController::mentions()
 	 *
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMentionSuggestion[], array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMentionSuggestion>, array{}>
 	 * @throws CannotReachRemoteException
 	 *
 	 * 200: List of mention suggestions returned
@@ -480,8 +467,9 @@ class ChatController {
 			],
 		);
 
-		/** @var TalkChatMentionSuggestion[] $data */
+		/** @var list<TalkChatMentionSuggestion> $data */
 		$data = $this->proxy->getOCSData($proxy);
+		/** @var list<TalkChatMentionSuggestion> $data */
 		$data = $this->userConverter->convertAttendees($room, $data, 'source', 'id', 'label');
 
 		// FIXME post-load status information
