@@ -29,6 +29,7 @@ class MapsPluginLoader implements IEventListener {
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof BeforeTemplateRenderedEvent)) {
 			return;
@@ -46,6 +47,7 @@ class MapsPluginLoader implements IEventListener {
 		if (str_starts_with($this->request->getPathInfo(), '/apps/maps')) {
 			Util::addScript('spreed', 'talk-collections');
 			Util::addScript('spreed', 'talk-maps');
+			Util::addStyle('spreed', 'talk-maps');
 		}
 	}
 }
