@@ -15,26 +15,33 @@ use OCP\SetupCheck\SetupResult;
 
 class SIPConfiguration implements ISetupCheck {
 	public function __construct(
-		readonly protected Config $talkConfig,
-		readonly protected IL10N $l,
+		protected readonly Config $talkConfig,
+		protected readonly IL10N $l,
 	) {
 	}
 
+	#[\Override]
 	public function getCategory(): string {
 		return 'talk';
 	}
 
+	#[\Override]
 	public function getName(): string {
-		return $this->l->t('SIP dial-in');
+		$name = $this->l->t('SIP configuration');
+		if ($this->talkConfig->getSignalingMode() === Config::SIGNALING_INTERNAL) {
+			return '[skip] ' . $name;
+		}
+		return $name;
 	}
 
+	#[\Override]
 	public function run(): SetupResult {
-		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
-			return SetupResult::success();
+		if ($this->talkConfig->getSignalingMode() === Config::SIGNALING_INTERNAL) {
+			return SetupResult::success($this->l->t('Using the SIP functionality requires a High-performance backend.'));
 		}
 		if ($this->talkConfig->getSIPSharedSecret() === '' && $this->talkConfig->getDialInInfo() === '') {
-			return SetupResult::success();
+			return SetupResult::info($this->l->t('No SIP backend configured'));
 		}
-		return SetupResult::error($this->l->t('Using the SIP functionality requires a High-performance backend.'));
+		return SetupResult::success();
 	}
 }
