@@ -7,24 +7,14 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Definition;
 /** @internal */
 final class FunctionObject
 {
-    private FunctionDefinition $definition;
+    public readonly FunctionDefinition $definition;
 
     /** @var callable */
-    private $callback;
+    public readonly mixed $callback;
 
     public function __construct(FunctionDefinition $definition, callable $callback)
     {
         $this->definition = $definition;
         $this->callback = $callback;
     }
-
-    public function definition(): FunctionDefinition
-    {
-        return $this->definition;
-    }
-
-    public function callback(): callable
-    {
-        return $this->callback;
-    }
 }
