@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\ObjectType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\IsSingleton;
@@ -20,6 +22,11 @@ final class UndefinedObjectType implements Type
         return is_object($value);
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::functionCall('is_object', [$node]);
+    }
+
     public function matches(Type $other): bool
     {
         if ($other instanceof UnionType) {
@@ -32,6 +39,11 @@ final class UndefinedObjectType implements Type
             || $other instanceof MixedType;
     }
 
+    public function nativeType(): UndefinedObjectType
+    {
+        return $this;
+    }
+
     public function toString(): string
     {
         return 'object';
